#!/bin/sh

tmp=$(mktemp)
tmpdir=$(mktemp -d)

trap "exit 1" TERM
export TOP_PID=$$

cleanup() {
    msg="$@"

    echo "${msg}"
    rm -rf $tmp $tmpdir
    kill -s TERM $TOP_PID
}

usage() {
    echo boe
}

export found_file="NOTFOUND"

find_flir_mount() {
    cat /proc/mounts | cut -d\  -f2 | uniq | while read dir; do
        file="${dir}/FLIRVers.rsc"
        if [ -e "${file}" ]; then
	    echo "$file"
	    exit
	fi
    done
    echo NOTFOUND
}

rsc_file=$(find_flir_mount | head -1)

if [ $rsc_file = 'NOTFOUND' ]; then
    cleanup "Unable to find suitable Flir device."
fi

echo "Found resource file: $rsc_file"



CRC01=./crc01
template_file="E8.cfg_template"
e8_file="Flashfs/system/appcore.d/config.d/e8.cfg"
out_file="MY_E8.cfg"
fif_file=$(pwd)/E8_hack.fif

#flir_dir="/mnt/flir"
#rsc_file="${flir_dir}/FLIRVers.rsc"


if [ ! -e $CRC01 ]; then
    ./build.sh
    if [ ! -e $CRC01 ]; then
        echo "Build of crc01 failed horribly for some reason."
        cleanup
    fi   
fi

exit

if [ ! -e $rsc_file ]; then
    echo "Unable to find resource file: $rsc_file"
    exit -1
fi

serial=$(grep '^.version.product.serial' $rsc_file | cut -d\" -f2)

# Make sure serial number is 639xxxxx
echo $serial | grep >/dev/null 2>/dev/null '^639[0-9]\{5\}$' || cleanup "Invalid serial number: ${serial} (expecting 639xxxxx, where x is obviously a digit ;)"

echo "Found serial number: ${serial}"
echo "Generating E4 ==> E8 firmware patch for serial ${serial}: $(basename ${fif_file})"

(
cat $template_file | grep -v '^# ID '
echo "# ID ${serial}"
) | todos > $tmp

$CRC01 $tmp | grep '^# CRC01 ' | todos >> $tmp


mkdir -p ${tmpdir}/$(dirname ${e8_file})
mv $tmp ${tmpdir}/${e8_file}


# silently remove old .fif file
rm -f $fif_file

# Generate .fif firmware file (just a regular zip file)
echo
(
cd $tmpdir
# generate camera.cmd
echo "addfile ${e8_file}" | todos > camera.cmd
zip -r ${fif_file} *
)


cat <<__EOF__

- Download FLIR tools: http://cdn.cloud.flir.se/update/flir%20tools/4.0.13284.1003/flir%20tools.zip
- Install FLIR tools.
- Go to the install folder\bin
- Turn camera on and plug in USB
- Run FLIRInstallNet
- Browse to your  $(basename ${fif_file})  file
- Click Run FIF
- Unplug USB, remove battery and replace
- Enjoy!
- For updates see: http://www.eevblog.com/forum/testgear/flir-e4-thermal-imaging-camera-teardown/msg321956/#msg321956
__EOF__

cleanup
